<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he">
<context>
    <name>StatusNotifierConfiguration</name>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="14"/>
        <source>Status Notifier Settings</source>
        <translation>הגדרות מודיע מצבים</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="25"/>
        <source>Reverse the order of items</source>
        <translation>היפוך סדר הפריטים</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="39"/>
        <location filename="../statusnotifierconfiguration.ui" line="49"/>
        <source>An auto-hiding item will remain visible for this period if it needs attention.</source>
        <translation>פריט שמסתתר אוטומטית יישאר גלוי למשך הזמן הזה אם נדרשת התייחסות.</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="42"/>
        <source>Attention period:</source>
        <translation>תקופת ההתייחסות:</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="52"/>
        <source> minute(s)</source>
        <translation> דקות</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="83"/>
        <source>Change visibility of items</source>
        <translation>החלפת מצב חשיפה של פריטים</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="96"/>
        <source>Item</source>
        <translation>פריט</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.ui" line="101"/>
        <source>Visibility</source>
        <translation>נראות</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="87"/>
        <source>Always show</source>
        <translation>להציג תמיד</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="87"/>
        <source>Auto-hide</source>
        <translation>הסתרה אוטומטית</translation>
    </message>
    <message>
        <location filename="../statusnotifierconfiguration.cpp" line="87"/>
        <source>Always hide</source>
        <translation>להסתיר תמיד</translation>
    </message>
</context>
</TS>
